==> zn-plugin-workflow-0.1.5.tgz: package/web/src/component/instance/FlowTableInfo.js <==
var React = require('react');

module.exports = React.createClass({
	getInitialState: function () {
		return {

		};
	},
	__renderPrimary: function (table, data){
		var _value = data[0];
		return <div className="table">
			<ul className="values">
				{
					table.fields.map(function (item, index){
						return <li>
							<span className="key">{item.title}：</span>
							<span className="value">{_value[item.name]}</span>
						</li>;
					})
				}
			</ul>
		</div>;
	},
	__renderDeputy: function (table, data){
		return !!data.length ? <zn.react.Group title={table.zn_title} className="table">
			<ul className="table-row header">
				{
					table.fields.map(function (item, index){
						return <li><span>{item.title}</span></li>;
					})
				}
			</ul>
			{
				data.map(function (item, index){
					return <ul className="table-row item">
						{
							Object.keys(item).map(function (key, index){
								return <li data-tooltip={item[key]}><span>{item[key]}</span></li>;
							})
						}
					</ul>
				})
			}
		</zn.react.Group> : null;
	},
	render:function(){
		return (
			<div className="zn-plugin-workflow-instance-flow-table-info zn-plugin-workflow-panel" >
				<div className="title">单据表单</div>
				{
					this.props.fields.map(function (field, index){
						return field.primary ? this.__renderPrimary(field, zn.is(this.props.data[0], "array") ? this.props.data[index] : this.props.data) : this.__renderDeputy(field, this.props.data[index]);
					}.bind(this))
				}
			</div>
		);
	}
});

==> zn-plugin-workflow-0.1.14.tgz: package/web/src/component/instance/FlowTableInfo.js <==
var React = require('react');

module.exports = React.createClass({
	getInitialState: function () {
		return {

		};
	},
	__renderPrimary: function (table, data){
		var _value = data[0];
		return <div className="table">
			<ul className="values">
				{
					table.fields.map(function (item, index){
						if(item.title && _value[item.name]){
							return <li>
								<span className="key">{item.title}：</span>
								<span className="value">{_value[item.name]}</span>
							</li>;
						}
					})
				}
			</ul>
		</div>;
	},
	__renderDeputy: function (table, data){
		return !!data.length ? <zn.react.Group title={table.zn_title + " 共" + data.length + "条"} className="table">
			<ul className="table-row header">
				{
					table.fields.map(function (item, index){
						if(item.width){
							return <li style={{width: item.width}}><span>{item.title}</span></li>;
						}
					})
				}
			</ul>
			{
				data.map(function (item, index){
					return <ul className="table-row item">
						{
							table.fields.map(function (field, index){
								if(field.width){
									return <li style={{width: field.width}} data-tooltip={item[field.name]}><span>{item[field.name]}</span></li>;
								}
							})
						}
					</ul>
				})
			}
		</zn.react.Group> : null;
	},
	render:function(){
		return (
			<div className="zn-plugin-workflow-instance-flow-table-info zn-plugin-workflow-panel" >
				<div className="title">单据表单</div>
				{
					this.props.fields.map(function (field, index){
						return field.primary ? this.__renderPrimary(field, zn.is(this.props.data[0], "array") ? this.props.data[index] : this.props.data) : this.__renderDeputy(field, this.props.data[index]);
					}.bind(this))
				}
			</div>
		);
	}
});
